@@ -2,7 +2,8 @@ from plone.restapi.controlpanels.interfaces import IDexterityTypesControlpanel
 from plone.restapi.deserializer import json_body
 from plone.restapi.deserializer.controlpanels import ControlpanelDeserializeFromJson
 from plone.restapi.interfaces import IDeserializeFromJson
-from zope.component import adapter, queryMultiAdapter
+from zope.component import adapter
+from zope.component import queryMultiAdapter
 from zope.interface import implementer
 
 
