@@ -1,4 +1,5 @@
 from datetime import timedelta
+from decimal import Decimal
 from plone.app.contenttypes.interfaces import ILink
 from plone.app.textfield.interfaces import IRichText
 from plone.app.textfield.value import RichTextValue
@@ -18,6 +19,7 @@ from zope.publisher.interfaces.browser import IBrowserRequest
 from zope.schema.interfaces import IChoice
 from zope.schema.interfaces import ICollection
 from zope.schema.interfaces import IDatetime
+from zope.schema.interfaces import IDecimal
 from zope.schema.interfaces import IDict
 from zope.schema.interfaces import IField
 from zope.schema.interfaces import IFromUnicode
@@ -296,3 +298,13 @@ class RichTextFieldDeserializer(DefaultFieldDeserializer):
         )
         self.field.validate(value)
         return value
+
+
+@implementer(IFieldDeserializer)
+@adapter(IDecimal, IDexterityContent, IBrowserRequest)
+class DecimalFieldDeserializer(DefaultFieldDeserializer):
+    def __call__(self, value):
+        if not isinstance(value, Decimal):
+            value = Decimal(value)
+        self.field.validate(value)
+        return value
