@@ -1,5 +1,7 @@
 from copy import deepcopy
+from plone.restapi.bbb import IPloneSiteRoot
 from plone.restapi.behaviors import IBlocks
+from plone.restapi.deserializer.blocks import iterate_children
 from plone.restapi.deserializer.blocks import SlateBlockTransformer
 from plone.restapi.deserializer.blocks import transform_links
 from plone.restapi.interfaces import IBlockFieldSerializationTransformer
@@ -8,7 +10,6 @@ from plone.restapi.serializer.converters import json_compatible
 from plone.restapi.serializer.dxfields import DefaultFieldSerializer
 from plone.restapi.serializer.utils import uid_to_url
 from plone.schema import IJSONField
-from Products.CMFPlone.interfaces import IPloneSiteRoot
 from zope.component import adapter
 from zope.component import subscribers
 from zope.globalrequest import getRequest
@@ -190,3 +191,40 @@ class SlateBlockSerializer(SlateBlockSerializerBase):
 @adapter(IPloneSiteRoot, IBrowserRequest)
 class SlateBlockSerializerRoot(SlateBlockSerializerBase):
     """Serializer for site root"""
+
+
+class SlateTableBlockSerializerBase(SlateBlockSerializerBase):
+    """SlateBlockSerializerBase."""
+
+    order = 100
+    block_type = "slateTable"
+
+    def __call__(self, block):
+        """call"""
+        rows = block.get("table", {}).get("rows", [])
+        for row in rows:
+            cells = row.get("cells", [])
+
+            for cell in cells:
+                cellvalue = cell.get("value", [])
+                children = iterate_children(cellvalue or [])
+                for child in children:
+                    node_type = child.get("type")
+                    if node_type:
+                        handler = getattr(self, f"handle_{node_type}", None)
+                        if handler:
+                            handler(child)
+
+        return block
+
+
+@implementer(IBlockFieldSerializationTransformer)
+@adapter(IBlocks, IBrowserRequest)
+class SlateTableBlockSerializer(SlateTableBlockSerializerBase):
+    """Serializer for content-types with IBlocks behavior"""
+
+
+@implementer(IBlockFieldSerializationTransformer)
+@adapter(IPloneSiteRoot, IBrowserRequest)
+class SlateTableBlockSerializerRoot(SlateTableBlockSerializerBase):
+    """Serializer for site root"""
