@@ -1,12 +1,10 @@
-# -*- coding: utf-8 -*-
 from plone.restapi.interfaces import ISerializeToJson
 from plone.restapi.services import Service
 from zope.component import queryMultiAdapter
 
 
 class ContentGet(Service):
-    """Returns a serialized content object.
-    """
+    """Returns a serialized content object."""
 
     def reply(self):
         serializer = queryMultiAdapter((self.context, self.request), ISerializeToJson)
