@@ -4,12 +4,14 @@ from itertools import chain
 from plone.app.workflow.browser.sharing import merge_search_results
 from plone.namedfile.utils import stream_data
 from plone.restapi.interfaces import ISerializeToJson
-from plone.restapi.interfaces import ISerializeToJsonSummary
 from plone.restapi.services import Service
 from Products.CMFCore.utils import getToolByName
 from Products.CMFPlone.utils import normalizeString
+from Products.PlonePAS.tools.memberdata import MemberData
 from Products.PlonePAS.tools.membership import default_portrait
 from Products.PlonePAS.utils import decleanId
+from typing import Iterable
+from typing import Sequence
 from urllib.parse import parse_qs
 from zExceptions import BadRequest
 from zope.component import getMultiAdapter
@@ -17,8 +19,7 @@ from zope.component import queryMultiAdapter
 from zope.component.hooks import getSite
 from zope.interface import implementer
 from zope.publisher.interfaces import IPublishTraverse
-from Products.PlonePAS.tools.memberdata import MemberData
-from typing import Sequence, Iterable
+
 
 DEFAULT_SEARCH_RESULTS_LIMIT = 25
 
@@ -210,9 +211,7 @@ class UsersGet(Service):
             if not user:
                 self.request.response.setStatus(404)
                 return
-            serializer = queryMultiAdapter(
-                (user, self.request), ISerializeToJsonSummary
-            )
+            serializer = queryMultiAdapter((user, self.request), ISerializeToJson)
             return serializer()
         else:
             self.request.response.setStatus(401)
