@@ -241,7 +241,12 @@ class TestBlocksDeserializer(unittest.TestCase):
         )
 
         self.deserialize(
-            blocks={"123": {"@type": "foo", "href": self.portal.doc1.absolute_url()}}
+            blocks={
+                "123": {
+                    "@type": "foo",
+                    "href": self.portal.doc1.absolute_url(),
+                }
+            }
         )
         doc_uid = IUUID(self.portal.doc1)
 
@@ -251,11 +256,17 @@ class TestBlocksDeserializer(unittest.TestCase):
 
     def test_blocks_custom_block_doesnt_resolve_non_standard_fields(self):
         self.deserialize(
-            blocks={"123": {"@type": "foo", "link": self.portal.doc1.absolute_url()}}
+            blocks={
+                "123": {
+                    "@type": "foo",
+                    "link": self.portal.doc1.absolute_url(),
+                }
+            }
         )
 
         self.assertEqual(
-            self.portal.doc1.blocks["123"]["link"], self.portal.doc1.absolute_url()
+            self.portal.doc1.blocks["123"]["link"],
+            self.portal.doc1.absolute_url(),
         )
 
     def test_deserialize_blocks_smart_href_array_volto_object_browser(self):
@@ -276,7 +287,12 @@ class TestBlocksDeserializer(unittest.TestCase):
 
     def test_deserialize_blocks_smart_href_array(self):
         self.deserialize(
-            blocks={"123": {"@type": "foo", "href": [self.portal.doc1.absolute_url()]}}
+            blocks={
+                "123": {
+                    "@type": "foo",
+                    "href": [self.portal.doc1.absolute_url()],
+                }
+            }
         )
         doc_uid = IUUID(self.portal.doc1)
 
@@ -437,3 +453,102 @@ class TestBlocksDeserializer(unittest.TestCase):
             self.portal.doc1.blocks["123"]["href"][0]["@id"],
             "../..",
         )
+
+    def test_slate_table_block_deserializer(self):
+        blocks = {
+            "abc": {
+                "@type": "slateTable",
+                "table": {
+                    "hideHeaders": False,
+                    "fixed": True,
+                    "compact": False,
+                    "basic": False,
+                    "celled": True,
+                    "inverted": False,
+                    "striped": False,
+                    "rows": [
+                        {
+                            "key": "25k7t",
+                            "cells": [
+                                {
+                                    "key": "ajes8",
+                                    "type": "header",
+                                    "value": [
+                                        {
+                                            "type": "p",
+                                            "children": [{"text": "Table with links"}],
+                                        }
+                                    ],
+                                },
+                                {
+                                    "key": "cm2bj",
+                                    "type": "header",
+                                    "value": [
+                                        {
+                                            "type": "p",
+                                            "children": [{"text": "Table with links"}],
+                                        }
+                                    ],
+                                },
+                            ],
+                        },
+                        {
+                            "key": "6gteb",
+                            "cells": [
+                                {
+                                    "key": "1gs74",
+                                    "type": "data",
+                                    "value": [
+                                        {
+                                            "type": "p",
+                                            "children": [
+                                                {"text": ""},
+                                                {
+                                                    "type": "link",
+                                                    "data": {
+                                                        "url": self.portal.doc1.absolute_url()
+                                                    },
+                                                    "children": [
+                                                        {
+                                                            "text": (
+                                                                "This internal" " link"
+                                                            )
+                                                        }
+                                                    ],
+                                                },
+                                                {"text": ""},
+                                            ],
+                                        }
+                                    ],
+                                },
+                                {
+                                    "key": "ab93b",
+                                    "type": "data",
+                                    "value": [
+                                        {
+                                            "type": "p",
+                                            "children": [
+                                                {"text": "This "},
+                                                {
+                                                    "type": "link",
+                                                    "data": {
+                                                        "url": "https://google.com"
+                                                    },
+                                                    "children": [{"text": "external"}],
+                                                },
+                                                {"text": " link"},
+                                            ],
+                                        }
+                                    ],
+                                },
+                            ],
+                        },
+                    ],
+                },
+            }
+        }
+        res = self.deserialize(blocks=blocks)
+        rows = res.blocks["abc"]["table"]["rows"]
+        cell = rows[1]["cells"][0]
+        link = cell["value"][0]["children"][1]["data"]["url"]
+        self.assertTrue(link.startswith("../resolveuid/"))
