@@ -30,7 +30,7 @@ import json
 import unittest
 
 
-class AdapterCM(object):
+class AdapterCM:
     """Context manager that will temporarily register an adapter"""
 
     def __init__(self, adapter, from_, provides):
@@ -54,17 +54,17 @@ class TestDXContentSerializer(unittest.TestCase):
         self.portal = self.layer["portal"]
         self.request = self.layer["request"]
 
-        richtext_value = RichTextValue(u"Käfer", "text/plain", "text/html")
+        richtext_value = RichTextValue("Käfer", "text/plain", "text/html")
 
         self.portal.invokeFactory(
             "DXTestDocument",
-            id=u"doc1",
+            id="doc1",
             test_ascii_field="foo",
             test_asciiline_field="foo",
             test_bool_field=True,
             test_bytes_field="\xc3\xa4\xc3\xb6\xc3\xbc",
             test_bytesline_field="\xc3\xa4\xc3\xb6\xc3\xbc",
-            test_choice_field=u"foo",
+            test_choice_field="foo",
             test_date_field=date(2015, 7, 15),
             test_datetime_field=datetime(2015, 6, 20, 13, 22, 4),
             test_decimal_field=Decimal(1.1),
@@ -73,15 +73,15 @@ class TestDXContentSerializer(unittest.TestCase):
             test_frozenset_field=frozenset([1, 2, 3]),
             test_int_field=500,
             test_list_field=[1, "two", 3],
-            test_set_field=set(["a", "b", "c"]),
-            test_text_field=u"Käfer",
+            test_set_field={"a", "b", "c"},
+            test_text_field="Käfer",
             test_richtext_field=richtext_value,
-            test_textline_field=u"Käfer",
+            test_textline_field="Käfer",
             test_time_field=time(14, 15, 33),
             test_timedelta_field=timedelta(44),
             test_tuple_field=(1, 1),
-            test_readonly_field=u"readonly",
-            test_read_permission_field=u"Secret Stuff",
+            test_readonly_field="readonly",
+            test_read_permission_field="Secret Stuff",
         )
 
         self.portal.doc1.creation_date = DateTime("2015-04-27T10:14:48+00:00")
@@ -101,54 +101,54 @@ class TestDXContentSerializer(unittest.TestCase):
     @unittest.skip("We do not include the context at this point")
     def test_serializer_includes_context(self):
         obj = self.serialize()
-        self.assertIn(u"@context", obj)
-        self.assertEqual(u"http://www.w3.org/ns/hydra/context.jsonld", obj[u"@context"])
+        self.assertIn("@context", obj)
+        self.assertEqual("http://www.w3.org/ns/hydra/context.jsonld", obj["@context"])
 
     def test_serializer_includes_json_ld_id(self):
         obj = self.serialize()
-        self.assertIn(u"@id", obj)
-        self.assertEqual(self.portal.doc1.absolute_url(), obj[u"@id"])
+        self.assertIn("@id", obj)
+        self.assertEqual(self.portal.doc1.absolute_url(), obj["@id"])
 
     def test_serializer_includes_id(self):
         obj = self.serialize()
-        self.assertIn(u"id", obj)
-        self.assertEqual(self.portal.doc1.id, obj[u"id"])
+        self.assertIn("id", obj)
+        self.assertEqual(self.portal.doc1.id, obj["id"])
 
     def test_serializer_includes_type(self):
         obj = self.serialize()
-        self.assertIn(u"@type", obj)
-        self.assertEqual(self.portal.doc1.portal_type, obj[u"@type"])
+        self.assertIn("@type", obj)
+        self.assertEqual(self.portal.doc1.portal_type, obj["@type"])
 
     def test_serializer_includes_review_state(self):
         obj = self.serialize()
-        self.assertIn(u"review_state", obj)
-        self.assertEqual(u"private", obj[u"review_state"])
+        self.assertIn("review_state", obj)
+        self.assertEqual("private", obj["review_state"])
 
     def test_serializer_includes_uid(self):
         obj = self.serialize()
-        self.assertIn(u"UID", obj)
-        self.assertEqual(u"30314724b77a4ec0abbad03d262837aa", obj[u"UID"])
+        self.assertIn("UID", obj)
+        self.assertEqual("30314724b77a4ec0abbad03d262837aa", obj["UID"])
 
     def test_serializer_includes_creation_date(self):
         obj = self.serialize()
-        self.assertIn(u"created", obj)
-        self.assertEqual(u"2015-04-27T10:14:48+00:00", obj[u"created"])
+        self.assertIn("created", obj)
+        self.assertEqual("2015-04-27T10:14:48+00:00", obj["created"])
 
     def test_serializer_includes_modification_date(self):
         obj = self.serialize()
-        self.assertIn(u"modified", obj)
-        self.assertEqual(u"2015-04-27T10:24:11+00:00", obj[u"modified"])
+        self.assertIn("modified", obj)
+        self.assertEqual("2015-04-27T10:24:11+00:00", obj["modified"])
 
     def test_serializer_ignores_field_without_read_permission(self):
-        self.portal.doc1.test_read_permission_field = u"Secret Stuff"
+        self.portal.doc1.test_read_permission_field = "Secret Stuff"
         setRoles(self.portal, TEST_USER_ID, ["Member"])
-        self.assertNotIn(u"test_read_permission_field", self.serialize())
+        self.assertNotIn("test_read_permission_field", self.serialize())
 
     def test_serializer_includes_field_with_read_permission(self):
         setRoles(self.portal, TEST_USER_ID, ["Manager"])
         obj = self.serialize()
-        self.assertIn(u"test_read_permission_field", obj)
-        self.assertEqual(u"Secret Stuff", obj[u"test_read_permission_field"])
+        self.assertIn("test_read_permission_field", obj)
+        self.assertEqual("Secret Stuff", obj["test_read_permission_field"])
 
     def test_get_layout(self):
         current_layout = self.portal.doc1.getLayout()
@@ -180,7 +180,7 @@ class TestDXContentSerializer(unittest.TestCase):
         self.assertEqual(False, obj["is_folderish"])
 
     def test_get_is_folderish_in_folder(self):
-        self.portal.invokeFactory("Folder", id=u"folder")
+        self.portal.invokeFactory("Folder", id="folder")
         serializer = getMultiAdapter(
             (self.portal.folder, self.request), ISerializeToJson
         )
@@ -413,7 +413,7 @@ class TestDXContentSerializer(unittest.TestCase):
         This is then verfied.
         """
 
-        class RichtextTransform(object):
+        class RichtextTransform:
             """RichttextValue to show that the context is correctly passed
             in throughout the stack.
             """
@@ -433,7 +433,7 @@ class TestDXContentSerializer(unittest.TestCase):
 
     def test_allow_discussion_by_default(self):
         """Not globally addable, not fti enabled, not obj instance enabled"""
-        self.portal.invokeFactory("Document", id=u"doc2")
+        self.portal.invokeFactory("Document", id="doc2")
         serializer = getMultiAdapter((self.portal.doc2, self.request), ISerializeToJson)
         obj = serializer()
 
@@ -441,7 +441,7 @@ class TestDXContentSerializer(unittest.TestCase):
         self.assertEqual(False, obj["allow_discussion"])
 
     def test_allow_discussion_obj_instance_allows_but_not_global_enabled(self):
-        self.portal.invokeFactory("Document", id=u"doc2")
+        self.portal.invokeFactory("Document", id="doc2")
         self.portal.doc2.allow_discussion = True
         serializer = getMultiAdapter((self.portal.doc2, self.request), ISerializeToJson)
         obj = serializer()
@@ -450,7 +450,7 @@ class TestDXContentSerializer(unittest.TestCase):
         self.assertEqual(False, obj["allow_discussion"])
 
     def test_allow_discussion_fti_allows_not_global_enabled(self):
-        self.portal.invokeFactory("Document", id=u"doc2")
+        self.portal.invokeFactory("Document", id="doc2")
         portal_types = getToolByName(self.portal, "portal_types")
         document_fti = getattr(portal_types, self.portal.doc2.portal_type)
         document_fti.allow_discussion = True
@@ -461,7 +461,7 @@ class TestDXContentSerializer(unittest.TestCase):
         self.assertEqual(False, obj["allow_discussion"])
 
     def test_allow_discussion_allows_global_enabled_but_nothing_else(self):
-        self.portal.invokeFactory("Document", id=u"doc2")
+        self.portal.invokeFactory("Document", id="doc2")
         registry = queryUtility(IRegistry)
         settings = registry.forInterface(IDiscussionSettings, check=False)
         settings.globally_enabled = True
@@ -472,7 +472,7 @@ class TestDXContentSerializer(unittest.TestCase):
         self.assertEqual(False, obj["allow_discussion"])
 
     def test_allow_discussion_obj_instance_allows_global_enabled(self):
-        self.portal.invokeFactory("Document", id=u"doc2")
+        self.portal.invokeFactory("Document", id="doc2")
         registry = queryUtility(IRegistry)
         settings = registry.forInterface(IDiscussionSettings, check=False)
         settings.globally_enabled = True
@@ -484,7 +484,7 @@ class TestDXContentSerializer(unittest.TestCase):
         self.assertEqual(True, obj["allow_discussion"])
 
     def test_allow_discussion_obj_instance_not_set_global_enabled(self):
-        self.portal.invokeFactory("Document", id=u"doc2")
+        self.portal.invokeFactory("Document", id="doc2")
         registry = queryUtility(IRegistry)
         settings = registry.forInterface(IDiscussionSettings, check=False)
         settings.globally_enabled = True
@@ -495,7 +495,7 @@ class TestDXContentSerializer(unittest.TestCase):
         self.assertEqual(False, obj["allow_discussion"])
 
     def test_allow_discussion_fti_allows_allows_global_enabled(self):
-        self.portal.invokeFactory("Document", id=u"doc2")
+        self.portal.invokeFactory("Document", id="doc2")
         registry = queryUtility(IRegistry)
         settings = registry.forInterface(IDiscussionSettings, check=False)
         settings.globally_enabled = True
@@ -511,7 +511,7 @@ class TestDXContentSerializer(unittest.TestCase):
     def test_allow_discussion_fti_allows_allows_global_enabled_but_no_instance_allowed(
         self,
     ):  # noqa
-        self.portal.invokeFactory("Document", id=u"doc2")
+        self.portal.invokeFactory("Document", id="doc2")
         registry = queryUtility(IRegistry)
         settings = registry.forInterface(IDiscussionSettings, check=False)
         settings.globally_enabled = True
@@ -529,7 +529,7 @@ class TestDXContentSerializer(unittest.TestCase):
     def test_allow_discussion_fti_allows_allows_global_enabled_but_no_instance_set(
         self,
     ):  # noqa
-        self.portal.invokeFactory("Document", id=u"doc2")
+        self.portal.invokeFactory("Document", id="doc2")
         registry = queryUtility(IRegistry)
         settings = registry.forInterface(IDiscussionSettings, check=False)
         settings.globally_enabled = True
@@ -546,7 +546,7 @@ class TestDXContentSerializer(unittest.TestCase):
     def test_allow_discussion_fti_disallows_allows_global_enabled_but_instance_allowed(
         self,
     ):  # noqa
-        self.portal.invokeFactory("Document", id=u"doc2")
+        self.portal.invokeFactory("Document", id="doc2")
         registry = queryUtility(IRegistry)
         settings = registry.forInterface(IDiscussionSettings, check=False)
         settings.globally_enabled = True
@@ -583,15 +583,15 @@ class TestDXContentPrimaryFieldTargetUrl(unittest.TestCase):
 
         self.portal.invokeFactory(
             "DXTestDocument",
-            id=u"doc1",
+            id="doc1",
             test_primary_namedfile_field=NamedFile(
-                data=u"Spam and eggs", contentType=u"text/plain", filename=u"test.txt"
+                data="Spam and eggs", contentType="text/plain", filename="test.txt"
             ),
         )
 
         self.portal.invokeFactory(
             "DXTestDocument",
-            id=u"doc2",
+            id="doc2",
             test_primary_namedfile_field=None,
         )
 
@@ -608,10 +608,10 @@ class TestDXContentPrimaryFieldTargetUrl(unittest.TestCase):
         serializer = getMultiAdapter((self.portal.doc1, self.request), ISerializeToJson)
         data = serializer()
         self.assertIn("targetUrl", data)
-        download_url = u"/".join(
+        download_url = "/".join(
             [
                 self.portal.doc1.absolute_url(),
-                u"@@download/test_primary_namedfile_field",
+                "@@download/test_primary_namedfile_field",
             ]
         )
         self.assertEqual(data["targetUrl"], download_url)
