@@ -48,7 +48,7 @@ class TestSerializeUserToJsonAdapters(unittest.TestCase):
         self.assertEqual("ploneteam@plone.org", group.get("email"))
         self.assertEqual("Plone Team", group.get("title"))
         self.assertEqual("We are Plone", group.get("description"))
-        self.assertEqual(set(group["users"]), {"@id", "items_total", "items"})
+        self.assertEqual(set(group["members"]), {"@id", "items_total", "items"})
 
     def test_summary(self):
         group = self.serialize_summary(self.group)
