@@ -65,11 +65,10 @@ class TestGroupsEndpoint(unittest.TestCase):
 
         self.assertEqual(ptgroup.get("roles"), ["Authenticated"])
 
-        # We don't want the group members listed in the overview as there
-        # might be loads.
+        # # Assert batched list of group members
         self.assertTrue(
-            not any(["users" in group for group in response.json()]),
-            "Users key found in groups listing",
+            all(["members" in group for group in response.json()]),
+            "Members key found in groups listing",
         )
 
     def test_add_group(self):
@@ -115,7 +114,7 @@ class TestGroupsEndpoint(unittest.TestCase):
         self.assertEqual("ploneteam@plone.org", response.json().get("email"))
         self.assertEqual("Plone Team", response.json().get("title"))
         self.assertEqual("We are Plone", response.json().get("description"))
-        self.assertIn("users", response.json())
+        self.assertIn("members", response.json())
 
     def test_get_search_group_with_filter(self):
         response = self.api_session.get("/@groups", params={"query": "plo"})
